@@ -7,3 +7,8 @@ def _if_not_positive_raise(*args):
     for arg in args:
         if arg <= 0:
             raise ValueError ("At least one of the values wasn't a positive number.")
+
+def _if_not_int_raise(*args):
+    for arg in args:
+        if type(arg) != int:
+            raise ValueError ("At least one of the values wasn't an integer")
